__all__: list[str] = []

import cv2
import cv2.typing
import typing as _typing


# Enumerations
SCENE_SEPARATE: int
SCENE_INTERACTIVE: int
SCENE_SHOW_CS_CROSS: int
SCENE_AA: int
SCENE_OFFSCREEN: int
SCENE_SHADOWS: int
SceneSettings = int
"""One of [SCENE_SEPARATE, SCENE_INTERACTIVE, SCENE_SHOW_CS_CROSS, SCENE_AA, SCENE_OFFSCREEN, SCENE_SHADOWS]"""

MATERIAL_POINT_SIZE: int
MATERIAL_LINE_WIDTH: int
MATERIAL_OPACITY: int
MATERIAL_EMISSIVE: int
MATERIAL_DIFFUSE: int
MATERIAL_TEXTURE0: int
MATERIAL_TEXTURE: int
MATERIAL_TEXTURE1: int
MATERIAL_TEXTURE2: int
MATERIAL_TEXTURE3: int
MaterialProperty = int
"""One of [MATERIAL_POINT_SIZE, MATERIAL_LINE_WIDTH, MATERIAL_OPACITY, MATERIAL_EMISSIVE, MATERIAL_DIFFUSE, MATERIAL_TEXTURE0, MATERIAL_TEXTURE, MATERIAL_TEXTURE1, MATERIAL_TEXTURE2, MATERIAL_TEXTURE3]"""

ENTITY_MATERIAL: int
ENTITY_SCALE: int
ENTITY_AABB_WORLD: int
ENTITY_ANIMBLEND_MODE: int
ENTITY_CAST_SHADOWS: int
EntityProperty = int
"""One of [ENTITY_MATERIAL, ENTITY_SCALE, ENTITY_AABB_WORLD, ENTITY_ANIMBLEND_MODE, ENTITY_CAST_SHADOWS]"""



# Classes
class WindowScene:
    # Functions
    @_typing.overload
    def setBackground(self, image: cv2.typing.MatLike) -> None: ...
    @_typing.overload
    def setBackground(self, image: cv2.UMat) -> None: ...

    def setBackgroundColor(self, color: cv2.typing.Scalar) -> None: ...

    def setCompositors(self, names: _typing.Sequence[str]) -> None: ...

    @_typing.overload
    def createEntity(self, name: str, meshname: str, tvec: cv2.typing.MatLike | None = ..., rot: cv2.typing.MatLike | None = ...) -> None: ...
    @_typing.overload
    def createEntity(self, name: str, meshname: str, tvec: cv2.UMat | None = ..., rot: cv2.UMat | None = ...) -> None: ...

    def removeEntity(self, name: str) -> None: ...

    @_typing.overload
    def setEntityProperty(self, name: str, prop: int, value: str, subEntityIdx: int = ...) -> None: ...
    @_typing.overload
    def setEntityProperty(self, name: str, prop: int, value: cv2.typing.Scalar) -> None: ...

    @_typing.overload
    def getEntityProperty(self, name: str, prop: int, value: cv2.typing.MatLike | None = ...) -> cv2.typing.MatLike: ...
    @_typing.overload
    def getEntityProperty(self, name: str, prop: int, value: cv2.UMat | None = ...) -> cv2.UMat: ...

    @_typing.overload
    def createCameraEntity(self, name: str, K: cv2.typing.MatLike, imsize: cv2.typing.Size, zFar: float, tvec: cv2.typing.MatLike | None = ..., rot: cv2.typing.MatLike | None = ..., color: cv2.typing.Scalar = ...) -> cv2.typing.Rect2d: ...
    @_typing.overload
    def createCameraEntity(self, name: str, K: cv2.UMat, imsize: cv2.typing.Size, zFar: float, tvec: cv2.UMat | None = ..., rot: cv2.UMat | None = ..., color: cv2.typing.Scalar = ...) -> cv2.typing.Rect2d: ...

    @_typing.overload
    def createLightEntity(self, name: str, tvec: cv2.typing.MatLike | None = ..., rot: cv2.typing.MatLike | None = ..., diffuseColor: cv2.typing.Scalar = ..., specularColor: cv2.typing.Scalar = ...) -> None: ...
    @_typing.overload
    def createLightEntity(self, name: str, tvec: cv2.UMat | None = ..., rot: cv2.UMat | None = ..., diffuseColor: cv2.typing.Scalar = ..., specularColor: cv2.typing.Scalar = ...) -> None: ...

    @_typing.overload
    def updateEntityPose(self, name: str, tvec: cv2.typing.MatLike | None = ..., rot: cv2.typing.MatLike | None = ...) -> None: ...
    @_typing.overload
    def updateEntityPose(self, name: str, tvec: cv2.UMat | None = ..., rot: cv2.UMat | None = ...) -> None: ...

    @_typing.overload
    def setEntityPose(self, name: str, tvec: cv2.typing.MatLike | None = ..., rot: cv2.typing.MatLike | None = ..., invert: bool = ...) -> None: ...
    @_typing.overload
    def setEntityPose(self, name: str, tvec: cv2.UMat | None = ..., rot: cv2.UMat | None = ..., invert: bool = ...) -> None: ...

    @_typing.overload
    def getEntityPose(self, name: str, R: cv2.typing.MatLike | None = ..., tvec: cv2.typing.MatLike | None = ..., invert: bool = ...) -> tuple[cv2.typing.MatLike, cv2.typing.MatLike]: ...
    @_typing.overload
    def getEntityPose(self, name: str, R: cv2.UMat | None = ..., tvec: cv2.UMat | None = ..., invert: bool = ...) -> tuple[cv2.UMat, cv2.UMat]: ...

    def getEntityAnimations(self, name: str, out: _typing.Sequence[str]) -> None: ...

    def playEntityAnimation(self, name: str, animname: str, loop: bool = ...) -> None: ...

    def stopEntityAnimation(self, name: str, animname: str) -> None: ...

    @_typing.overload
    def getScreenshot(self, frame: cv2.typing.MatLike | None = ...) -> cv2.typing.MatLike: ...
    @_typing.overload
    def getScreenshot(self, frame: cv2.UMat | None = ...) -> cv2.UMat: ...

    @_typing.overload
    def getCompositorTexture(self, compname: str, texname: str, out: cv2.typing.MatLike | None = ..., mrtIndex: int = ...) -> cv2.typing.MatLike: ...
    @_typing.overload
    def getCompositorTexture(self, compname: str, texname: str, out: cv2.UMat | None = ..., mrtIndex: int = ...) -> cv2.UMat: ...

    @_typing.overload
    def getDepth(self, depth: cv2.typing.MatLike | None = ...) -> cv2.typing.MatLike: ...
    @_typing.overload
    def getDepth(self, depth: cv2.UMat | None = ...) -> cv2.UMat: ...

    @_typing.overload
    def fixCameraYawAxis(self, useFixed: bool, up: cv2.typing.MatLike | None = ...) -> None: ...
    @_typing.overload
    def fixCameraYawAxis(self, useFixed: bool, up: cv2.UMat | None = ...) -> None: ...

    @_typing.overload
    def setCameraPose(self, tvec: cv2.typing.MatLike | None = ..., rot: cv2.typing.MatLike | None = ..., invert: bool = ...) -> None: ...
    @_typing.overload
    def setCameraPose(self, tvec: cv2.UMat | None = ..., rot: cv2.UMat | None = ..., invert: bool = ...) -> None: ...

    @_typing.overload
    def setCameraLookAt(self, target: str, offset: cv2.typing.MatLike | None = ...) -> None: ...
    @_typing.overload
    def setCameraLookAt(self, target: str, offset: cv2.UMat | None = ...) -> None: ...

    @_typing.overload
    def setEntityLookAt(self, origin: str, target: str, offset: cv2.typing.MatLike | None = ...) -> None: ...
    @_typing.overload
    def setEntityLookAt(self, origin: str, target: str, offset: cv2.UMat | None = ...) -> None: ...

    @_typing.overload
    def getCameraPose(self, R: cv2.typing.MatLike | None = ..., tvec: cv2.typing.MatLike | None = ..., invert: bool = ...) -> tuple[cv2.typing.MatLike, cv2.typing.MatLike]: ...
    @_typing.overload
    def getCameraPose(self, R: cv2.UMat | None = ..., tvec: cv2.UMat | None = ..., invert: bool = ...) -> tuple[cv2.UMat, cv2.UMat]: ...

    @_typing.overload
    def setCameraIntrinsics(self, K: cv2.typing.MatLike, imsize: cv2.typing.Size, zNear: float = ..., zFar: float = ...) -> None: ...
    @_typing.overload
    def setCameraIntrinsics(self, K: cv2.UMat, imsize: cv2.typing.Size, zNear: float = ..., zFar: float = ...) -> None: ...

    def update(self) -> None: ...



# Functions
def addResourceLocation(path: str) -> None: ...

def createGridMesh(name: str, size: cv2.typing.Size2f, segments: cv2.typing.Size = ...) -> None: ...

@_typing.overload
def createPlaneMesh(name: str, size: cv2.typing.Size2f, image: cv2.typing.MatLike | None = ...) -> None: ...
@_typing.overload
def createPlaneMesh(name: str, size: cv2.typing.Size2f, image: cv2.UMat | None = ...) -> None: ...

@_typing.overload
def createPointCloudMesh(name: str, vertices: cv2.typing.MatLike, colors: cv2.typing.MatLike | None = ...) -> None: ...
@_typing.overload
def createPointCloudMesh(name: str, vertices: cv2.UMat, colors: cv2.UMat | None = ...) -> None: ...

@_typing.overload
def createTriangleMesh(name: str, vertices: cv2.typing.MatLike, normals: cv2.typing.MatLike | None = ..., indices: cv2.typing.MatLike | None = ...) -> None: ...
@_typing.overload
def createTriangleMesh(name: str, vertices: cv2.UMat, normals: cv2.UMat | None = ..., indices: cv2.UMat | None = ...) -> None: ...

def createWindow(title: str, size: cv2.typing.Size, flags: int = ...) -> WindowScene: ...

@_typing.overload
def setMaterialProperty(name: str, prop: int, value: cv2.typing.Scalar) -> None: ...
@_typing.overload
def setMaterialProperty(name: str, prop: int, value: str) -> None: ...
@_typing.overload
def setMaterialProperty(name: str, prop: str, value: cv2.typing.Scalar) -> None: ...

@_typing.overload
def setMaterialTexture(name: str, prop: int, value: cv2.typing.MatLike) -> None: ...
@_typing.overload
def setMaterialTexture(name: str, prop: int, value: cv2.UMat) -> None: ...

@_typing.overload
def updateTexture(name: str, image: cv2.typing.MatLike) -> None: ...
@_typing.overload
def updateTexture(name: str, image: cv2.UMat) -> None: ...

def waitKey(delay: int = ...) -> int: ...


